==> php54-owncloud-8.0.3.tgz: share/owncloud/apps/files/l10n/mk.js <==
OC.L10N.register(
    "files",
    {
    "Unknown error" : "Непозната грешка",
    "Could not move %s - File with this name already exists" : "Не можам да го преместам %s - Датотека со такво име веќе постои",
    "Could not move %s" : "Не можам да ги префрлам %s",
    "File name cannot be empty." : "Името на датотеката не може да биде празно.",
    "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." : "Неправилно име. , '\\', '/', '<', '>', ':', '\"', '|', '?' и '*' не се дозволени.",
    "Not a valid source" : "Не е валиден извор",
    "Error while downloading %s to %s" : "Грешка додека преземам %s to %s",
    "Error when creating the file" : "Грешка при креирање на датотека",
    "Folder name cannot be empty." : "Името на папката не може да биде празно.",
    "Error when creating the folder" : "Грешка при креирање на папка",
    "Unable to set upload directory." : "Не може да се постави папката за префрлање на податоци.",
    "Invalid Token" : "Грешен токен",
    "No file was uploaded. Unknown error" : "Ниту еден фајл не се вчита. Непозната грешка",
    "There is no error, the file uploaded with success" : "Датотеката беше успешно подигната.",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Подигнатата датотека ја надминува upload_max_filesize директивата во php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Големината на датотеката ја надминува MAX_FILE_SIZE директивата која беше специфицирана во HTML формата",
    "The uploaded file was only partially uploaded" : "Датотеката беше само делумно подигната.",
    "No file was uploaded" : "Не беше подигната датотека.",
    "Missing a temporary folder" : "Недостасува привремена папка",
    "Failed to write to disk" : "Неуспеав да запишам на диск",
    "Not enough storage available" : "Нема доволно слободен сториџ",
    "Upload failed. Could not find uploaded file" : "Префрлањето е неуспешно. Не можам да го најдам префрлената датотека.",
    "Invalid directory." : "Погрешна папка.",
    "Files" : "Датотеки",
    "Favorites" : "Омилени",
    "Home" : "Дома",
    "Upload cancelled." : "Преземањето е прекинато.",
    "Could not get result from server." : "Не можам да добијам резултат од серверот.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Подигање на датотека е во тек. Напуштење на страницата ќе го прекине.",
    "URL cannot be empty" : "URL-то не може да биде празно",
    "{new_name} already exists" : "{new_name} веќе постои",
    "Could not create file" : "Не множам да креирам датотека",
    "Could not create folder" : "Не можам да креирам папка",
    "Rename" : "Преименувај",
    "Delete" : "Избриши",
    "Unshare" : "Не споделувај",
    "Download" : "Преземи",
    "Select" : "Избери",
    "Pending" : "Чека",
    "Error moving file" : "Грешка при префрлање на датотека",
    "Error" : "Грешка",
    "Could not rename file" : "Не можам да ја преименувам датотеката",
    "Name" : "Име",
    "Size" : "Големина",
    "Modified" : "Променето",
    "_%n folder_::_%n folders_" : ["",""],
    "_%n file_::_%n files_" : ["",""],
    "_Uploading %n file_::_Uploading %n files_" : ["",""],
    "Your storage is full, files can not be updated or synced anymore!" : "Вашиот сториџ е полн, датотеките веќе не можат да се освежуваат или синхронизираат!",
    "Your storage is almost full ({usedSpacePercent}%)" : "Вашиот сториџ е скоро полн ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["",""],
    "{dirs} and {files}" : "{dirs} и {files}",
    "%s could not be renamed" : "%s не може да биде преименуван",
    "File handling" : "Ракување со датотеки",
    "Maximum upload size" : "Максимална големина за подигање",
    "max. possible: " : "макс. можно:",
    "Save" : "Сними",
    "Settings" : "Подесувања",
    "WebDAV" : "WebDAV",
    "New" : "Ново",
    "Text file" : "Текстуална датотека",
    "New folder" : "Нова папка",
    "Folder" : "Папка",
    "From link" : "Од врска",
    "Upload" : "Подигни",
    "Cancel upload" : "Откажи прикачување",
    "Upload too large" : "Фајлот кој се вчитува е преголем",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Датотеките кои се обидувате да ги подигнете ја надминуваат максималната големина за подигнување датотеки на овој сервер.",
    "Files are being scanned, please wait." : "Се скенираат датотеки, ве молам почекајте."
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");

==> php54-owncloud-8.1.0.tgz: share/owncloud/apps/files/l10n/mk.js <==
OC.L10N.register(
    "files",
    {
    "Unknown error" : "Непозната грешка",
    "Could not move %s - File with this name already exists" : "Не можам да го преместам %s - Датотека со такво име веќе постои",
    "Could not move %s" : "Не можам да ги префрлам %s",
    "Error when creating the file" : "Грешка при креирање на датотека",
    "Error when creating the folder" : "Грешка при креирање на папка",
    "Unable to set upload directory." : "Не може да се постави папката за префрлање на податоци.",
    "Invalid Token" : "Грешен токен",
    "No file was uploaded. Unknown error" : "Ниту еден фајл не се вчита. Непозната грешка",
    "There is no error, the file uploaded with success" : "Датотеката беше успешно подигната.",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Подигнатата датотека ја надминува upload_max_filesize директивата во php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Големината на датотеката ја надминува MAX_FILE_SIZE директивата која беше специфицирана во HTML формата",
    "The uploaded file was only partially uploaded" : "Датотеката беше само делумно подигната.",
    "No file was uploaded" : "Не беше подигната датотека.",
    "Missing a temporary folder" : "Недостасува привремена папка",
    "Failed to write to disk" : "Неуспеав да запишам на диск",
    "Not enough storage available" : "Нема доволно слободен сториџ",
    "Upload failed. Could not find uploaded file" : "Префрлањето е неуспешно. Не можам да го најдам префрлената датотека.",
    "Invalid directory." : "Погрешна папка.",
    "Files" : "Датотеки",
    "Favorites" : "Омилени",
    "Home" : "Дома",
    "Upload cancelled." : "Преземањето е прекинато.",
    "Could not get result from server." : "Не можам да добијам резултат од серверот.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Подигање на датотека е во тек. Напуштење на страницата ќе го прекине.",
    "{new_name} already exists" : "{new_name} веќе постои",
    "Could not create file" : "Не множам да креирам датотека",
    "Could not create folder" : "Не можам да креирам папка",
    "Rename" : "Преименувај",
    "Delete" : "Избриши",
    "Unshare" : "Не споделувај",
    "Download" : "Преземи",
    "Select" : "Избери",
    "Pending" : "Чека",
    "Error moving file" : "Грешка при префрлање на датотека",
    "Error" : "Грешка",
    "Could not rename file" : "Не можам да ја преименувам датотеката",
    "Name" : "Име",
    "Size" : "Големина",
    "Modified" : "Променето",
    "File name cannot be empty." : "Името на датотеката не може да биде празно.",
    "Your storage is full, files can not be updated or synced anymore!" : "Вашиот сториџ е полн, датотеките веќе не можат да се освежуваат или синхронизираат!",
    "Your storage is almost full ({usedSpacePercent}%)" : "Вашиот сториџ е скоро полн ({usedSpacePercent}%)",
    "{dirs} and {files}" : "{dirs} и {files}",
    "You created %1$s" : "Вие креиравте %1$s",
    "%2$s created %1$s" : "%2$s креирано %1$s",
    "You changed %1$s" : "Вие изменивте %1$s",
    "%2$s changed %1$s" : "%2$s променето %1$s",
    "You deleted %1$s" : "Вие избришавте %1$s",
    "%2$s deleted %1$s" : "%2$s избришани %1$s",
    "%s could not be renamed" : "%s не може да биде преименуван",
    "Upload (max. %s)" : "Префрлање (макс. %s)",
    "File handling" : "Ракување со датотеки",
    "Maximum upload size" : "Максимална големина за подигање",
    "max. possible: " : "макс. можно:",
    "Save" : "Сними",
    "Settings" : "Подесувања",
    "WebDAV" : "WebDAV",
    "New" : "Ново",
    "Text file" : "Текстуална датотека",
    "New folder" : "Нова папка",
    "Folder" : "Папка",
    "Upload" : "Подигни",
    "Cancel upload" : "Откажи прикачување",
    "Upload too large" : "Фајлот кој се вчитува е преголем",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Датотеките кои се обидувате да ги подигнете ја надминуваат максималната големина за подигнување датотеки на овој сервер.",
    "Files are being scanned, please wait." : "Се скенираат датотеки, ве молам почекајте."
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
